%% Classify .ms2 files with Fpress
% This script runs the algorithm detailed in
% "French Press: Filtering tandem mass spectra for quality" 
% by Sergey Feldman, Barbara Frewen, Michael J. MacCoss, and Maya R. Gupta.  

%% step 1: import test data (.ms2 files)

trainDir = 'train';
testDir = 'test'; % folder with ms2s
import_test_data % returns 

%% step 2: extract features

X.features = cellfun(@getOptimalFeatures,X.data,num2cell(X.mz), 'UniformOutput',0); 
X.features = cell2mat(X.features);

% if you wish to save the imported data, features. & file look-up-table
saveName = 'test_run'; % 
save([testDir '\' saveName '.data'],'X','LUT')

%% step 3: classify data with provided model

load([trainDir '\RF_model.mat']) % loading pre-computed RF model
extra_options.importance = 0; % RF options (0 = (Default) Don't, 1 = calculate)
[Yest,votes] = classRF_predict(X.features,model,extra_options); 
% Yest are class estimates -> '1' means good and '2' means bad
probs = votes./repmat(sum(votes,2),1,size(votes,2)); % probabilities of being in class 1 & 2

%% step 4: get ROC curve and auroc95 score if real labels are available
if exist('Ytest','var');
    [tp,fp] = roc(Ytest,probs(:,1));
    ROCthresh = 0.95;
    auroc95_score = auroc(tp,fp,ROCthresh);
end