function X = readMS2(fileName,dataDir)

% Function for reading in .ms2 files.  
% Inputs: file name and data directory.  
% Output: X
%         X.id - vector of spectrum IDs
%         X.mz - vector of spectrum mass to charge ratios
%         X.data - struct of the spectra

dataID = fopen([dataDir '\' fileName]);
% identifier = num2str(prod(fileName(1:end-4)-0));
% identifier = identifier(1:6);

% skip through header lines, which all start with 'H'
line = fgetl(dataID);
while line(1) == 'H'
    line = fgetl(dataID);
end

% reading in ID and m/z of the protein from the line that starts with S
N = 500000; % preallocating some huge vector, otherwise it's much slower
X.id = -ones(N,1); % later will remove all lines that have a -1 for the id
X.mz = zeros(N,1);
X.data = cell(N,1);
k = 0; 
while line ~= -1
    if line(1) == 'S'; % 'S' means we've hit a new spectrum
        k = k + 1; 
        t = regexp(line,'\s', 'split');
        X.id(k,1) = str2double(t{2});
        X.mz(k,1) = str2double(t{4});
        while line(1) > '9' % we keep going until we hit a number
            line = fgetl(dataID);
        end
        l = 1;
        while line(1) ~= 'S' && line(1) ~= -1 % get all the subsequent numbers
            X.data{k,1}(l,:) = str2num(line);
            line = fgetl(dataID);
            l = l + 1;
        end
    end
end

fclose(dataID); % close file

% trim the -1 ids that remain at the tail of the vector
fields = fieldnames(X); % getting field names
killFlag = X.id == -1;
for k = 1:length(fields); 
    X.(fields{k})(killFlag) = []; 
end